==> inventive-inventory-1.3.2-sources.jar: net/inventive_mods/inventive_inventory/features/profiles/gui/ProfilesNamingScreen.java <==
package net.inventive_mods.inventive_inventory.features.profiles.gui;

import net.inventive_mods.inventive_inventory.InventiveInventory;
import net.inventive_mods.inventive_inventory.features.profiles.ProfileHandler;
import net.minecraft.class_2561;
import net.minecraft.class_342;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_5244;
import net.minecraft.class_7842;
import net.minecraft.class_8667;
import org.lwjgl.glfw.GLFW;

public class ProfilesNamingScreen extends class_437 {
    private class_342 textFieldWidget;

    public ProfilesNamingScreen() {
        super(class_2561.method_30163("TextFieldScreen"));
        int width = InventiveInventory.getClient().method_22683().method_4486();
        int height = InventiveInventory.getClient().method_22683().method_4502();
        this.method_25423(InventiveInventory.getClient(), width, height);
    }

    @Override
    protected void method_25426() {
        super.method_25426();
        if (this.field_22787 == null) return;
        int centerX = this.field_22789 / 2;
        int centerY = this.field_22790 / 2;

        class_8667 layout = class_8667.method_52741();
        class_7842 textWidget = new class_7842(150, 10, class_2561.method_43471("profiles.screen.naming.text_field.inventive_inventory.placeholder"), this.field_22787.field_1772);
        this.textFieldWidget = new class_342(this.field_22787.field_1772, 150, 20, class_2561.method_43473());
        this.textFieldWidget.method_47404(class_2561.method_43471("profiles.screen.naming.text_field.inventive_inventory.placeholder"));
        class_4185 doneButton = class_4185.method_46430(class_5244.field_24334, (button) -> createProfile()).method_46431();

        layout.method_52736(textWidget);
        layout.method_52736(this.textFieldWidget);
        layout.method_52736(doneButton);
        layout.method_52735(5);
        layout.method_48222();
        layout.method_48229(centerX - layout.method_25368() / 2, centerY - centerY / 2);
        layout.method_48206(this::method_37063);
    }

    @Override
    public boolean method_25404(int keyCode, int scanCode, int modifiers) {
        super.method_25404(keyCode, scanCode, modifiers);
        if (GLFW.GLFW_KEY_ENTER == keyCode) createProfile();
        return true;
    }

    private void createProfile() {
        String name = this.textFieldWidget.method_1882();
        ProfileHandler.create(name, ProfileHandler.getAvailableProfileKey());
        this.method_25419();
    }
}

==> inventive-inventory-1.3.3-sources.jar: net/inventive_mods/inventive_inventory/features/profiles/gui/ProfilesNamingScreen.java <==
package net.inventive_mods.inventive_inventory.features.profiles.gui;

import net.inventive_mods.inventive_inventory.util.widgets.DirectionalLayoutWidget;
import net.minecraft.class_2561;
import net.minecraft.class_342;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_5244;
import net.minecraft.class_7842;
import net.inventive_mods.inventive_inventory.InventiveInventory;
import net.inventive_mods.inventive_inventory.features.profiles.ProfileHandler;
import org.lwjgl.glfw.GLFW;

public class ProfilesNamingScreen extends class_437 {
    private class_342 textFieldWidget;

    public ProfilesNamingScreen() {
        super(class_2561.method_30163("TextFieldScreen"));
        int width = InventiveInventory.getClient().method_22683().method_4486();
        int height = InventiveInventory.getClient().method_22683().method_4502();
        this.method_25423(InventiveInventory.getClient(), width, height);
    }

    @Override
    protected void method_25426() {
        super.method_25426();
        if (this.field_22787 == null) return;
        int centerX = this.field_22789 / 2;
        int centerY = this.field_22790 / 2;

        DirectionalLayoutWidget layout = DirectionalLayoutWidget.vertical();
        class_7842 textWidget = new class_7842(150, 10, class_2561.method_43471("profiles.screen.naming.text_field.inventive_inventory.placeholder"), this.field_22787.field_1772);
        this.textFieldWidget = new class_342(this.field_22787.field_1772, 0, 0, 150, 20, class_2561.method_43473());
        this.textFieldWidget.method_47404(class_2561.method_43471("profiles.screen.naming.text_field.inventive_inventory.placeholder"));
        class_4185 doneButton = class_4185.method_46430(class_5244.field_24334, (button) -> createProfile()).method_46431();

        layout.add(textWidget);
        layout.add(this.textFieldWidget);
        layout.add(doneButton);
        layout.spacing(5);
        layout.method_48222();
        layout.method_48229(centerX - layout.method_25368() / 2, centerY - centerY / 2);
        layout.method_48206(this::method_37063);
    }

    @Override
    public boolean method_25404(int keyCode, int scanCode, int modifiers) {
        super.method_25404(keyCode, scanCode, modifiers);
        if (GLFW.GLFW_KEY_ENTER == keyCode) createProfile();
        return true;
    }

    private void createProfile() {
        String name = this.textFieldWidget.method_1882();
        ProfileHandler.create(name, ProfileHandler.getAvailableProfileKey());
        this.method_25419();
    }
}
